<?php

namespace ChrisLondon\ForteApi\Models;

class PayMethod
{
	/**
	 * The identification number of the associated account. For example, act_5551236.
	 *
	 * @var string
	 * @required
	 */
	public $accountId;

	/**
	 * The identification number of the associated location. For example, loc_1234568
	 *
	 * @var string
	 * @required
	 */
	public $locationId;

	/**
	 * A unique string used to represent a customer. For example, cst_SoGUG6mcLUS1nVzYBIbk3g. [max length = 26]
	 *
	 * NOTE: When a merchant passes a customer token with a transaction, Forte ignores any other customer data in favor
	 * of the default data stored with the token.
	 *
	 * @var string
	 * @maxLength 26
	 */
	public $customerToken;

	/**
	 * A unique string used to represent a payment method. For example, mth_1578436587.
	 * [max length = 26]
	 *
	 * @var string
	 * @maxLength 26
	 */
	public $payMethodToken;

	/**
	 * A single use token generated by Forte.js.
	 *
	 * @var string
	 */
	public $oneTimeToken;

	/**
	 * A friendly, customer-defined name for the payment method. For example,
	 * "Moms Credit Card," "Work Credit Card," "Visa - 1234," etc.
	 * [max length = 50]
	 *
	 * @var string
	 * @rewuired
	 * @maxLength 50
	 */
	public $label;

	/**
	 * The Card object
	 * @var Card
	 */
	public $card;

	/**
	 * the ECheck Object
	 * @var ECheck
	 */
	public $eCheck;

	/**
	 * A short description of the pay method.
	 *
	 * @var string
	 */
	public $notes;
}